@@ -5,7 +5,6 @@
 import os
 import subprocess
 import sys
-import sphinx_rtd_theme
 import recommonmark.parser
 
 
@@ -64,8 +63,8 @@ release = _release['__version__']
 # templates_path = ['_templates']
 
 master_doc = 'index'
-project = 'ipywidgets and jupyter-js-widgets'
-copyright = '2016, Jupyter Team, https://jupyter.org'
+project = 'Jupyter Widgets'
+copyright = '2017 Project Jupyter'
 author = 'Jupyter Team'
 
 language = None
@@ -75,6 +74,7 @@ todo_include_todos = False
 
 
 # -- html --------------------------
+html_theme = 'sphinx_rtd_theme'
 
 # html_static_path = ['_static']
 htmlhelp_basename = 'ipywidgetsdoc'
